@@ -17,12 +17,12 @@ test_that("ssd_gof", {
   expect_is(x, "tbl")
   expect_identical(colnames(x), c("dist", "ad", "ks", "cvm", "aic", "aicc", "bic"))
   expect_identical(x$dist, "lnorm")
-  expect_equal(x$ad, 0.5070335, tolerance = 0.0000001)
-  expect_equal(x$ks, 0.1065143, tolerance = 0.0000001)
-  expect_equal(x$cvm, 0.07033164, tolerance = 0.0000001)
-  expect_equal(x$aic, 239.0284, tolerance = 0.00001)
-  expect_equal(x$aicc, 239.5084, tolerance = 0.00001)
-  expect_equal(x$bic, 241.6928, tolerance = 0.00001)
+  expect_equal(x$ad, 0.506765995104718)
+  expect_equal(x$ks, 0.106478603062667)
+  expect_equal(x$cvm, 0.0702966462329144)
+  expect_equal(x$aic, 239.028434223307)
+  expect_equal(x$aicc, 239.508434223307)
+  expect_equal(x$bic, 241.692843243657)
 
   xs <- ssd_gof(boron_dists)
   expect_is(xs, "tbl")
