@@ -13,24 +13,24 @@
 #    limitations under the License.
 
 test_that("dllogis", {
-  expect_equal(dllogis(exp(3), 3, 1), 0.003720046, tolerance = 0.0000001)
-  expect_equal(dllogis(exp(4), 3, 1), 0.001200358, tolerance = 0.0000001)
+  expect_equal(dllogis(exp(3), 1, 3), 0.003720046)
+  expect_equal(dllogis(exp(4), 1, 3), 0.001200358)
 })
 
 test_that("fit llogis", {
-  dist <- ssdtools:::ssd_fit_dist(ssdtools::boron_data, dist = "llogis")
+  dist <- ssd_fit_dist(ssdtools::boron_data, dist = "llogis")
 
   expect_true(is.fitdist(dist))
   expect_equal(
     coef(dist),
-    c(lscale = 2.6261248978507, lshape = 0.740309228071107)
+    c(locationlog = 2.6261248978507, scalelog = 0.740309228071107)
   )
 })
 
 test_that("pqllogis", {
-  expect_equal(log(qllogis(0.5, 1, 1)), 1, tolerance = 0.000001)
-  expect_equal(pllogis(exp(3), 1, 1), 0.8807971, tolerance = 0.0000001)
-  expect_equal(pllogis(exp(4), 1, 1), 0.9525741, tolerance = 0.0000001)
+  expect_equal(log(qllogis(0.5, 1, 1)), 1)
+  expect_equal(pllogis(exp(3), 1, 1), 0.880797077977882)
+  expect_equal(pllogis(exp(4), 1, 1), 0.952574126822433)
   expect_identical(pllogis(qllogis(0.5, 3, 1), 3, 1), 0.5)
 })
 
@@ -38,5 +38,5 @@ test_that("rllogis", {
   set.seed(99)
   r <- rllogis(100000, 1, 1)
   expect_identical(length(r), 100000L)
-  expect_equal(mean(log(r)), 1, tolerance = 0.1)
+  expect_equal(mean(log(r)), 0.99552614238909)
 })
